References — FastMBAR 1.0-rc documentation

Skip to main content
`Ctrl`+`K`

# References

Please consider citing the following references if FastMBAR is used in your projects.

1. Xinqiang Ding, Jonah Z. Vilseck, Charles L. Brooks III. (2019). Fast Solver for Large Scale Multistate Bennett Acceptance Ratio Equations. J. Chem. Theory Comput.

2. Xinqiang Ding, Jonah Z. Vilseck, Ryan L. Hayes, Charles L. Brooks III. (2017). Gibbs Sampler-based λ-dynamics and Rao–Blackwell Estimator for Alchemical Free Energy Calculation. J. Chem. Theory Comput.

3. Shirts, Michael R., and John D. Chodera. (2008) Statistically Optimal Analysis of Samples from Multiple Equilibrium States. J. Chem. Phys.

4. Kong A, McCullagh P, Meng XL, Nicolae D, Tan Z. (2003) A theory of statistical models for Monte Carlo integration. J. R. Stat. Soc. Ser. B Stat. Methodol.

5. Bennett, Charles H. (1976) Efficient Estimation of Free Energy Differences from Monte Carlo Data. J. Comput. Phys.